USE [master]
GO

/****** Object:  Database [NorthStarLiveManager]    Script Date: 07/15/2010 23:28:17 ******/
IF  EXISTS (SELECT name FROM sys.databases WHERE name = N'NorthStarLiveManager')
DROP DATABASE [NorthStarLiveManager]
GO

USE [master]
GO

/****** Object:  Database [NorthStarLiveManager]    Script Date: 07/15/2010 23:28:17 ******/
CREATE DATABASE [NorthStarLiveManager] 
GO


USE [NorthStarLiveManager]
GO

/****** Object:  Table [dbo].[tblSystemThresholds]    Script Date: 07/15/2010 23:30:46 ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[tblSystemThresholds](
	[ThresholdID] [int] NOT NULL,
	[Measurement] [nvarchar](64) NULL,
	[ThresholdName] [nvarchar](64) NOT NULL,
	[ThresholdValue] [int] NOT NULL,
	[Notes] [nvarchar](512) NULL,
 CONSTRAINT [PK_tblSystemThresholds] PRIMARY KEY CLUSTERED 
(
	[ThresholdID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
/****** Object:  Table [dbo].[tblSystemClientActivities]    Script Date: 07/15/2010 23:30:46 ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[tblSystemClientActivities](
	[HostAddress] [nvarchar](64) NOT NULL,
	[ClientAddress] [nvarchar](64) NOT NULL,
	[Service] [nvarchar](64) NULL,
	[Operation] [nvarchar](64) NULL,
	[Timestamp] [datetime] NOT NULL,
	[TimeElapsed]  AS (datediff(minute,[TimeStamp],getdate()))
) ON [PRIMARY]
GO
/****** Object:  Table [dbo].[tblSystemUsers]    Script Date: 07/15/2010 23:30:47 ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[tblSystemUsers](
	[UserID] [int] IDENTITY(1,1) NOT NULL,
	[UserName] [nvarchar](64) NOT NULL,
	[FirstName] [nvarchar](64) NULL,
	[LastName] [nvarchar](64) NULL,
	[Email] [nvarchar](64) NULL,
	[ModifiedOn] [datetime] NULL CONSTRAINT [DF__tblSystem__Modif__21B6055D]  DEFAULT (getdate()),
 CONSTRAINT [PK_tblSystemUsers] PRIMARY KEY CLUSTERED 
(
	[UserID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY],
 CONSTRAINT [CK_tblSystemUsers_UniqueUserName] UNIQUE NONCLUSTERED 
(
	[UserName] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
/****** Object:  Table [dbo].[tblSystemUserAddressMappings]    Script Date: 07/15/2010 23:30:47 ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[tblSystemUserAddressMappings](
	[UserID] [int] NOT NULL,
	[HostAddress] [nvarchar](64) NOT NULL,
	[ClientAddress] [nvarchar](64) NOT NULL,
	[Notes] [nvarchar](512) NULL,
 CONSTRAINT [PK_tblSystemMonitorUserConcerns] PRIMARY KEY CLUSTERED 
(
	[UserID] ASC,
	[HostAddress] ASC,
	[ClientAddress] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
/****** Object:  ForeignKey [FK_tblSystemUserAddressMappings_tblSystemUsers]    Script Date: 07/15/2010 23:30:47 ******/
ALTER TABLE [dbo].[tblSystemUserAddressMappings]  WITH CHECK ADD  CONSTRAINT [FK_tblSystemUserAddressMappings_tblSystemUsers] FOREIGN KEY([UserID])
REFERENCES [dbo].[tblSystemUsers] ([UserID])
GO
ALTER TABLE [dbo].[tblSystemUserAddressMappings] CHECK CONSTRAINT [FK_tblSystemUserAddressMappings_tblSystemUsers]
GO


/*==================================================
Create views
==================================================*/

USE [NorthStarLiveManager]
GO

/****** Object:  View [dbo].[vwThresholdLevels]    Script Date: 07/15/2010 23:31:51 ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE VIEW [dbo].[vwThresholdLevels]
AS
SELECT     Measurement, SUM(NormalLevel) AS NormalLevel, SUM(AlarmLevel) AS AlarmLevel, SUM(CriticalLevel) AS CriticalLevel
FROM         (SELECT     Measurement, (CASE ThresholdID WHEN 10 THEN ThresholdValue END) AS NormalLevel, (CASE ThresholdID WHEN 11 THEN ThresholdValue END) 
                                              AS AlarmLevel, (CASE ThresholdID WHEN 12 THEN ThresholdValue END) AS CriticalLevel
                       FROM          dbo.tblSystemThresholds) AS T
GROUP BY Measurement
GO
/****** Object:  View [dbo].[vwSystemNetworkStatus]    Script Date: 07/15/2010 23:31:51 ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE VIEW [dbo].[vwSystemNetworkStatus]
AS
SELECT     dbo.tblSystemClientActivities.HostAddress, dbo.tblSystemClientActivities.ClientAddress, dbo.tblSystemClientActivities.Timestamp, 
                      dbo.tblSystemClientActivities.TimeElapsed, 
                      CASE WHEN TimeElapsed > CriticalLevel THEN 'Critical' WHEN TimeElapsed > AlarmLevel THEN 'Alarm' ELSE 'Normal' END AS Status
FROM         dbo.tblSystemClientActivities CROSS JOIN
                      dbo.vwThresholdLevels
GO
/****** Object:  View [dbo].[vwSystemUserAddressMappings]    Script Date: 07/15/2010 23:31:51 ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE VIEW [dbo].[vwSystemUserAddressMappings]
AS
SELECT     dbo.tblSystemUserAddressMappings.UserID, dbo.tblSystemUsers.UserName, dbo.tblSystemUserAddressMappings.HostAddress, 
                      dbo.tblSystemUserAddressMappings.ClientAddress, dbo.tblSystemUserAddressMappings.Notes
FROM         dbo.tblSystemUserAddressMappings INNER JOIN
                      dbo.tblSystemUsers ON dbo.tblSystemUserAddressMappings.UserID = dbo.tblSystemUsers.UserID
GO
/****** Object:  View [dbo].[vwSystemNetworkStatusForMailerService]    Script Date: 07/15/2010 23:31:51 ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE VIEW [dbo].[vwSystemNetworkStatusForMailerService]
AS
SELECT     dbo.tblSystemUserAddressMappings.UserID, dbo.tblSystemUsers.Email, dbo.tblSystemUsers.UserName, dbo.tblSystemUsers.LastName, 
                      dbo.tblSystemUsers.FirstName, dbo.vwSystemNetworkStatus.HostAddress, dbo.vwSystemNetworkStatus.ClientAddress, dbo.tblSystemUserAddressMappings.Notes, 
                      dbo.vwSystemNetworkStatus.Timestamp, dbo.vwSystemNetworkStatus.TimeElapsed, dbo.vwSystemNetworkStatus.Status
FROM         dbo.tblSystemUserAddressMappings INNER JOIN
                      dbo.vwSystemNetworkStatus ON dbo.tblSystemUserAddressMappings.HostAddress = dbo.vwSystemNetworkStatus.HostAddress AND 
                      dbo.tblSystemUserAddressMappings.ClientAddress = dbo.vwSystemNetworkStatus.ClientAddress INNER JOIN
                      dbo.tblSystemUsers ON dbo.tblSystemUserAddressMappings.UserID = dbo.tblSystemUsers.UserID
GO


/****** Object:  View [dbo].[vwSystemNetworkStatusByUserAdmin]    Script Date: 07/15/2010 23:31:51 ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE VIEW [dbo].[vwSystemNetworkStatusByUserAdmin]
AS
SELECT        dbo.tblSystemUserAddressMappings.UserID, dbo.vwSystemNetworkStatus.HostAddress, dbo.vwSystemNetworkStatus.ClientAddress, 
                         dbo.vwSystemNetworkStatus.Timestamp, dbo.vwSystemNetworkStatus.TimeElapsed, dbo.vwSystemNetworkStatus.Status
FROM            dbo.tblSystemUserAddressMappings INNER JOIN
                         dbo.vwSystemNetworkStatus ON dbo.tblSystemUserAddressMappings.HostAddress = dbo.vwSystemNetworkStatus.HostAddress AND 
                         dbo.tblSystemUserAddressMappings.ClientAddress = dbo.vwSystemNetworkStatus.ClientAddress
GO


/*==================================================
Create Stored Procedures
==================================================*/

USE [NorthStarLiveManager]
GO

/****** Object:  StoredProcedure [dbo].[spWriteSystemStatusSubscription]    Script Date: 07/15/2010 23:33:02 ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE PROCEDURE [dbo].[spWriteSystemStatusSubscription]
	@UserName nvarchar(128), 
	@HostAddress nvarchar(64),
	@ClientAddress nvarchar(64),
    @Notes nvarchar(512) = NULL
AS
BEGIN
	SET TRANSACTION ISOLATION LEVEL READ UNCOMMITTED
	SET NOCOUNT ON;

	INSERT INTO tblSystemStatusSubscriptions (SubscriberUserName, HostAddress, ClientAddress, Notes) VALUES (@UserName, @HostAddress, @ClientAddress, @Notes)

    RETURN @@ROWCOUNT
END
GO
/****** Object:  StoredProcedure [dbo].[spGetSystemStatusSubscriptions]    Script Date: 07/15/2010 23:33:02 ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE PROCEDURE [dbo].[spGetSystemStatusSubscriptions]
AS
BEGIN
	SET NOCOUNT ON;

	SELECT SubscriberUserName, HostAddress, ClientAddress, Notes from tblSystemStatusSubscriptions
    ORDER BY SubscriberUserName
END
GO
/****** Object:  StoredProcedure [dbo].[spGetClientActivityStatusList]    Script Date: 07/15/2010 23:33:02 ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE Procedure [dbo].[spGetClientActivityStatusList]
As
set nocount on
SET TRANSACTION ISOLATION LEVEL READ UNCOMMITTED

--
-- Get the client actvity list
--
select [HostAddress], [ClientAddress], [Service], [Operation], [Timestamp], [ElapsedMinutes], AlarmLevel
from ClientConnectivityStatusView
order by [HostAddress], [ClientAddress], AlarmLevel

return @@rowcount
GO
/****** Object:  StoredProcedure [dbo].[spGetClientActivities]    Script Date: 07/15/2010 23:33:02 ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE Procedure [dbo].[spGetClientActivities]
As
set nocount on
SET TRANSACTION ISOLATION LEVEL READ UNCOMMITTED

--
-- Get the client actvity list
--
select [HostAddress], [ClientAddress], [Service], [Operation], [Timestamp] 
from tblSystemClientActivities
order by [HostAddress], [ClientAddress], [Timestamp]

return @@rowcount
GO
/****** Object:  StoredProcedure [dbo].[spDeleteClientActivity]    Script Date: 07/15/2010 23:33:02 ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
/*============================================================
NorthstarLive VERSION 2.0.1.11
=============================================================*/
Create Procedure [dbo].[spDeleteClientActivity]
(
	@ClientAddress as int
)
As
set nocount on
SET TRANSACTION ISOLATION LEVEL READ UNCOMMITTED


delete tblSystemClientActivities
where [ClientAddress] = @ClientAddress

return @@rowcount
GO
/****** Object:  StoredProcedure [dbo].[spWriteClientActivity]    Script Date: 07/15/2010 23:33:02 ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE Procedure [dbo].[spWriteClientActivity]
(
	@Client nvarchar(64),
	@Host nvarchar(64),
	@Service nvarchar(128),
	@Operation nvarchar(128),
	@Timestamp datetime
)
As
set nocount on
SET TRANSACTION ISOLATION LEVEL READ UNCOMMITTED


--if exists(select * from tblSystemClientActivities where [ClientAddress] = @Client AND [HostAddress] = @Host AND [Service] = @Service AND Operation = @Operation)
--begin
--	--
--	-- Update existing record
--	--
--	update tblSystemClientActivities
--		set [Timestamp] = @Timestamp
--	where [ClientAddress] = @Client AND HostAddress = @Host AND [Service] = @Service AND Operation = @Operation
--end
--else
--begin
--	--
--	-- Insert a new record
--	--
--	insert tblSystemClientActivities ([ClientAddress], [HostAddress], [Service], [Operation], [Timestamp] ) 
--		values (@Client, @Host, @Service, @Operation, @Timestamp)
--end


if exists(select * from tblSystemClientActivities where [ClientAddress] = @Client AND [HostAddress] = @Host )
begin
	--
	-- Update existing record
	--
	update tblSystemClientActivities
		set [Timestamp] = @Timestamp
	where [ClientAddress] = @Client AND HostAddress = @Host
end
else
begin
	--
	-- Insert a new record
	--
	insert tblSystemClientActivities ([ClientAddress], [HostAddress], [Service], [Operation], [Timestamp] ) 
		values (@Client, @Host, 'N/A', 'N/A', @Timestamp)
end






return @@rowcount
GO


/*==================================================
Insert default data
==================================================*/

Use NorthstarLiveManager
GO

DELETE FROM tblSystemThresholds
GO

INSERT INTO [NorthStarLiveManager].[dbo].[tblSystemThresholds]
           ([ThresholdID]
           ,[Measurement]
           ,[ThresholdName]
           ,[ThresholdValue]
           ,[Notes])
     VALUES
           ( 10
           , 'NorthStarLive Network'
           , 'NormalLevel'
           , 5
           , null
           )

INSERT INTO [NorthStarLiveManager].[dbo].[tblSystemThresholds]
           ([ThresholdID]
           ,[Measurement]
           ,[ThresholdName]
           ,[ThresholdValue]
           ,[Notes])
     VALUES
           ( 11
           , 'NorthStarLive Network'
           , 'AlarmLevel'
           , 10
           , null
           )


INSERT INTO [NorthStarLiveManager].[dbo].[tblSystemThresholds]
           ([ThresholdID]
           ,[Measurement]
           ,[ThresholdName]
           ,[ThresholdValue]
           ,[Notes])
     VALUES
           ( 12
           , 'NorthStarLive Network'
           , 'CriticalLevel'
           , 15
           , null
           )

